@@ -12,7 +12,7 @@ Usage::
     session_client: IoTDataPlaneClient = session.client("iot-data")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, IO, TYPE_CHECKING, Union
+from typing import Any, Dict, IO, TYPE_CHECKING, Type, Union
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_iot_data.type_defs import (
     DeleteThingShadowResponseTypeDef,
@@ -25,17 +25,17 @@ __all__ = ("IoTDataPlaneClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    ConflictException: Boto3ClientError
-    InternalFailureException: Boto3ClientError
-    InvalidRequestException: Boto3ClientError
-    MethodNotAllowedException: Boto3ClientError
-    RequestEntityTooLargeException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
-    ServiceUnavailableException: Boto3ClientError
-    ThrottlingException: Boto3ClientError
-    UnauthorizedException: Boto3ClientError
-    UnsupportedDocumentEncodingException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    ConflictException: Type[Boto3ClientError]
+    InternalFailureException: Type[Boto3ClientError]
+    InvalidRequestException: Type[Boto3ClientError]
+    MethodNotAllowedException: Type[Boto3ClientError]
+    RequestEntityTooLargeException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
+    ServiceUnavailableException: Type[Boto3ClientError]
+    ThrottlingException: Type[Boto3ClientError]
+    UnauthorizedException: Type[Boto3ClientError]
+    UnsupportedDocumentEncodingException: Type[Boto3ClientError]
 
 
 class IoTDataPlaneClient:
